# $Id: answercall.tcl,v 1.2 1998/08/31 15:30:54 michael Exp $

#----------------------------------------------------------------------#
# This script is called after the call is answered. Here you can do    #
# message playing, message recording and all other things you want.    #
#                                                                      #
# The following global variables can be used in this script:           #
#                                                                      #
# vbxv_savetime   - The time in unix format the script was started     #
# vbxv_callerid   - The remote's caller ID                             #
# vbxv_callername - The remote's caller name                           #
# vbxv_localphone - The local called phone number                      #
# vbxv_username   - The local user                                     #
# vbxv_userhome   - The local user's spool directory                   #
# vbxv_usedscript - The name of this script :-)                        #
# vbxv_saveulaw   - The name of the voice data record file             #
# vbxv_savevbox   - The name of the voice data description file        #
#----------------------------------------------------------------------#
# The script runs under user permissions!                              #
#----------------------------------------------------------------------#

################################################################################
################################################################################
################################################################################

proc playmsg {msg} {
    global DEBUG
    global stage
    append msg ".ulaw"
    set result [vbox_voice p $msg]
    switch $result {
	OK      {#normal termination}
        SUSPEND {}
        HANGUP  {#remote hung up}
        default {#touchtone}
    }
    if {$DEBUG} then {
	vbox_log D "---> playmsg \"$msg\" result: $result"
    }
    return $result
}

proc ansage {} {
    global DEBUG
    global stage
    global vbxv_savetime
    set result [vbox_voice p standard.ulaw beep.ulaw]
    switch $result {
	OK      {#normal termination
		    #recmsg 120
		    recmsg $vbxv_savetime
		}
        SUSPEND {}
        HANGUP  {#remote hung up}
        default {#touchtone
		    switch $result {
		    "*1#" {recmsg 5}
		    "*2#" {recmsg 10}
		    "*0#" {askpin}
		    }
		}
    }
    if {$DEBUG} then {
	vbox_log D "---> ansage result: $result"
    }
    return $result
}

proc askpin {} {
    global DEBUG
    global stage
    set result [playmsg askpin]
    unsetdtmfseq all
    setdtmfseq "*31415#"
    set result [waitsek 20]
    switch $result {
	OK      {playmsg pintimeout}
        SUSPEND {}
        HANGUP  {#remote hung up}
        default {#touchtone
		    switch $result {
		    "*31415#" {playmsg pinok
			       sec_menu
			      }
		    default {playmsg pinwrong}
		    }
		}
    }    
    if {$DEBUG} then {
	vbox_log D "---> askpin result: $result"
    }
}

proc sec_menu {} {
    global DEBUG
    global stage
    set result [playmsg logged_in]
    set result [playmsg sec_menu]    
    unsetdtmfseq all
    setdtmfseq "*1#"
    setdtmfseq "*2#"
    setdtmfseq "*3#"
    setdtmfseq "*4#"
    set result [waitsek 20]
    switch $result {
	OK      {playmsg pintimeout}
        SUSPEND {}
        HANGUP  {#remote hung up}
        default {#touchtone
		    switch $result {
		    "*1#" {#modemcallback
			    playmsg modemcallback
			  }
		    "*2#" {#isdncallback 
			    playmsg isdncallback
			  }
		    "*3#" {#serverneustart 
			    playmsg rebootserver
			  }
		    "*4#" {#email? 
			    playmsg emailcheck
			  }
		    }
		}
    }    
    if {$DEBUG} then {
	vbox_log D "---> askpin result: $result"
    }    
}

proc confirm_action {} {
    global DEBUG
    global stage
    set ret 0
    unsetdtmfseq all
    setdtmfseq "*1#"
    setdtmfseq "*2#"
    set result [waitsek 20]
    switch $result {
	OK      {set ret 1}
        SUSPEND {}
        HANGUP  {#remote hung up}
        default {#touchtone
		    switch $result {
		    "*1#" {#modemcallback
			    set ret 1
			  }
		    "*2#" {#isdncallback 
			    set ret 0
			  }
		    }
		}
    }    
    if {$DEBUG} then {
	vbox_log D "---> confirm_action result: $result"
    }
    return $ret
}

proc waitsek {sek} {
    return [vbox_voice w $sek]
}

proc recstart {} {
    global DEBUG
    global stage
    vbox_voice r start
}

proc recstop {} {
    global DEBUG
    global stage
    vbox_voice r stop
}

proc recmsg {timeout} {
    global DEBUG
    global stage
    recstart
    set result [waitsek $timeout]
    switch $result {
	OK      {#normal termination
			vbox_voice p suspend.ulaw
		        recstop
		}
        SUSPEND {
			vbox_voice p suspend.ulaw
		        recstop
		}
        HANGUP  {#remote hung up}
        default {#touchtone
		    
		}
    }
    recstop
}

proc setdtmfseq {dtmf} {
    global DEBUG
    global stage
    vbox_breaklist a $dtmf
}

proc unsetdtmfseq {dtmf} {
    global DEBUG
    global stage
    if {$dtmf == "all"} then {
	vbox_breaklist c
    } else {
        vbox_breaklist r $dtmf
    }
}

proc dtmfhandler {dtmf} {
    global DEBUG
    global stage

}

proc init {} {
    global DEBUG
    global stage
    set DEBUG 1
    vbox_breaklist c
    setdtmfseq "*1#"
    setdtmfseq "*2#"
    setdtmfseq "*0#"    
}

proc mailnotify {} {
    global vbxv_saveulaw vbxv_savevbox vbxv_username vbxv_callername
    if {([file isfile "$vbxv_saveulaw"]) && ([file isfile "$vbxv_savevbox"])} {
        vbox_log A "Mailing recorded message to \"$vbxv_username\"..."
        exec mail -s "Neue Nachricht auf Anrufbeantworter ($vbxv_callername)"  $vbxv_username <$vbxv_savevbox
    }
}


proc main {} {
    global DEBUG
    global stage
    set stage "init"
    init
    vbox_voice a stop
    set stage "ansage"
    ansage
    vbox_voice a stop
    mailnotify
}

main

#if {([file isfile "$vbxv_saveulaw"]) && ([file isfile "$vbxv_savevbox"])} {
#
#    vbox_log A "Mailing recorded message to \"$vbxv_username\"..."
#
#    exec mutt -s "New vbox message ($vbxv_callername)" -a "$vbxv_saveulaw" $vbxv_username <$vbxv_savevbox
#}
